<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Arkivhåndtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>En simpel skrivebordsuafhængig, Qt baseret arkivhåndtering</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Udviklere</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programmering:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Arkivhåndtering er afledt fra følgende programmer:
* Engrampa fra MATE desktop
* File Roller fra Gnome desktop
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt Arkivhåndtering

Ophavsret (C) 2020 LXQt holdet

Dette program er fri software. Du kan redistribuere og/eller
modificere det under de betingelserne som er angivet i GNU General
Public License, som er udgivet af Free Software Foundation. Enten
version 2 af licensen eller (efter eget valg) enhver senere version.

Dette program distribueres i håb om at det vil vise sig nyttigt, men
UDEN NOGEN FORM FOR GARANTI, uden selv de underforståede garantier
omkring SALGBARHED eller EGNETHED TIL ET BESTEMT FORMÅL. Yderligere
detaljer kan læses i GNU General Public License.

Du skulle have modtaget en kopi af GNU General Public License sammen
med dette program. Hvis ikke, så skriv til Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Arkivtype ikke understøttet.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 filer (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Alle understøttede formater</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Kan ikke udføre kommandoen.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Ukendt kommando.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Kommandoen blev ikke afsluttet korrekt.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Adgangskode påkrævet.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Delarkiv mangler.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Forkert tegnsæt.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Filformat ikke understøttet.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Ukendt fejl opstod.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Split i delarkiver på</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Adgangskode:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Kryptér også indholdslisten</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="12"/>
        <source>Create Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createfiledialog.cpp" line="14"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Pak ud</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>Pak all&amp;e filer ud</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Pak valgt&amp;e filer ud</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Handlinger</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Genskab foldere</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Overskriv eksisterende filer</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Pak ikke ældre filer ud</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="11"/>
        <source>Extract</source>
        <translation type="unfinished">Pak ud</translation>
    </message>
    <message>
        <location filename="../extractfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>File Archiver</source>
        <translation>Arkivhåndtering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Filtrer filer...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>&amp;Ikonstørrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Main Toolbar</source>
        <translation>Hovedværktøjslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>&amp;Open</source>
        <translation>&amp;Åben</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="213"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Save &amp;As</source>
        <translation>Gem &amp;Som</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Skift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Extract</source>
        <translation>Pak &amp;Ud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;Test</source>
        <translation>&amp;Test</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>&amp;Properties</source>
        <translation>&amp;Egenskaber</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="252"/>
        <source>Alt+Return</source>
        <translation>Alt+Retur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>Cu&amp;t</source>
        <translation>K&amp;lip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiér</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>&amp;Paste</source>
        <translation>&amp;Indsæt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>&amp;Rename</source>
        <translation>&amp;Omdøb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="317"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>&amp;Select All</source>
        <translation>Vælg &amp;alle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>&amp;Find</source>
        <translation>&amp;Søg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>&amp;Add Files</source>
        <translation>&amp;Tilføj filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Add F&amp;older</source>
        <translation>&amp;Tilføj mapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Pass&amp;word</source>
        <translation>Adgangs&amp;kode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="373"/>
        <source>&amp;Toolbar</source>
        <translation>Værk&amp;tøjslinie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Statuslinie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Mappetræ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="406"/>
        <source>S&amp;how as Folder</source>
        <translation>&amp;Vis som mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Skift+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Show &amp;All Files</source>
        <translation>Vis &amp;Alle filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Skift+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>St&amp;op</source>
        <translation>St&amp;op</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>&amp;Reload</source>
        <translation>Gen&amp;indlæs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Filename &amp;Encoding</source>
        <translation>Indko&amp;dning af filnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>&amp;View Selected Items</source>
        <translation>Frem&amp;vis valgte emner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filtrér</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>&amp;Expand</source>
        <translation>Pak &amp;Ud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Skift+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Skift+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>&amp;Collapse</source>
        <translation>&amp;Fold sammen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>16 px</source>
        <translation>16 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>24 px</source>
        <translation>24 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>32 px</source>
        <translation>32 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>48 px</source>
        <translation>48 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="397"/>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Add only if &amp;newer</source>
        <translation>Tilføj kun hvis &amp;nyere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Er du sikker på, at du vil slette de valgte filer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="754"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>No errors have been found.</source>
        <translation>Der er ikke fundet nogen fejl.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="923"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Add Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Add Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>N/A</source>
        <translation>I/T</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>Uncompressed Size:</source>
        <translation>Ukomprimeret størrelse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Compression Ratio:</source>
        <translation>Kompressions forhold:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1033"/>
        <source>Link to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <source>File name</source>
        <translation>Filnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>File Type</source>
        <translation>Filtype</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>File Size</source>
        <translation>Filstørrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Modified</source>
        <translation>Ændret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1076"/>
        <source>Encrypted</source>
        <translation>Krypteret</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1102"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n fil</numerusform>
            <numerusform>%n filer</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Krypter indholdslisten</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Vis adgangskode</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Adgangskode:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; Adgangskoden vil blive brugt til at kryptere de filer som du tilføjer til det aktive arkiv, og til at dekryptere og udtrække filer fra det aktive arkiv. Når arkivet bliver lukket, vil adgangskoden blive slettet.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7-Zip (.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar komprimeret med 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace (.ace)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar (.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar (.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj (.arj)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar komprimeret med bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar komprimeret med bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet (.cab)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar-komprimeret Comic Book (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip-komprimeret Comic Book (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar komprimeret med gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>Ear (.ear)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Selvudpakkende zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar (.jar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha (.lzh)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip (.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar komprimeret med lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar komprimeret med lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar komprimeret med lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar komprimeret med lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Windows Imaging Format (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>RAR (.rar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar ukomprimeret (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar komprimeret med compress (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War (.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz (.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar komprimeret med xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar komprimeret med (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo (.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip (.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Tilføjer fil: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>Udpakker fil: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation>%d %B %Y, %H:%M</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Fjerner fil: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Sletter filer i arkiv</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Pakker arkiv om</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Pakker arkiv ud</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Fil ikke fundet.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Arkivtype ikke understøttet.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Arkiv ikke fundet</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Du har ikke de rigtige tilladelser.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Denne type arkiv kan ikke ændres</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Du kan ikke tilføje et arkiv til det selv.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Kunne ikke finde delarkiv: %s</translation>
    </message>
</context>
</TS>
